@@ -87,14 +87,14 @@ class Web(object):
     if not fullurl.scheme or not fullurl.netloc:
       return True
     try:
-      with TRACER.timed('Resolving', V=2):
+      with TRACER.timed('Resolving %s' % fullurl.hostname, V=2):
         if not deadline(self._resolves, fullurl, timeout=self.NS_TIMEOUT_SECS):
           TRACER.log('Failed to resolve %s' % url)
           return False
     except Timeout:
       TRACER.log('Timed out resolving %s' % fullurl.hostname)
       return False
-    with TRACER.timed('Connecting', V=2):
+    with TRACER.timed('Connecting to %s' % fullurl.hostname, V=2):
       return self._reachable(fullurl, conn_timeout=conn_timeout)
 
   def maybe_local_url(self, url):
@@ -108,7 +108,7 @@ class Web(object):
       Wrapper in front of urlopen that more gracefully handles odd network environments.
     """
     url = self.maybe_local_url(url)
-    with TRACER.timed('Fetching', V=1):
+    with TRACER.timed('Fetching %s' % url, V=1):
       if not self.reachable(url, conn_timeout=conn_timeout):
         raise urllib_error.URLError('Could not reach %s within deadline.' % url)
       return urllib_request.urlopen(url, **kw)
@@ -166,7 +166,7 @@ class CachedWeb(object):
   def encode_url(self, url, conn_timeout=None):
     target, target_tmp, headers, headers_tmp = self.translate_all(url)
     with contextlib.closing(self.really_open(url, conn_timeout=conn_timeout)) as http_fp:
-      with TRACER.timed('Caching', V=2):
+      with TRACER.timed('Caching %s' % url, V=2):
         with open(target_tmp, 'wb') as disk_fp:
           disk_fp.write(http_fp.read())
         with open(headers_tmp, 'wb') as headers_fp:
@@ -198,7 +198,7 @@ class CachedWeb(object):
   def open(self, url, ttl=None, conn_timeout=None):
     """Return a file-like object with the content of the url."""
     expired = self.expired(url, ttl=ttl)
-    with TRACER.timed('Opening %s' % ('(cached)' if not expired else ''), V=1):
+    with TRACER.timed('Opening %s' % ('(cached)' if not expired else '(uncached)'), V=1):
       if expired:
         try:
           self.cache(url, conn_timeout=conn_timeout)
